aboutsummaryrefslogtreecommitdiff
path: root/src/NLMS~.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/NLMS~.c')
-rw-r--r--src/NLMS~.c23
1 files changed, 9 insertions, 14 deletions
diff --git a/src/NLMS~.c b/src/NLMS~.c
index ade883e..f54efc6 100644
--- a/src/NLMS~.c
+++ b/src/NLMS~.c
@@ -6,11 +6,6 @@ lib iem_adaptfilt written by Markus Noisternig & Thomas Musil
noisternig_AT_iem.at; musil_AT_iem.at
(c) Institute of Electronic Music and Acoustics, Graz Austria 2005 */
-#ifdef NT
-#pragma warning( disable : 4244 )
-#pragma warning( disable : 4305 )
-#endif
-
#include "m_pd.h"
#include "iemlib.h"
@@ -149,7 +144,7 @@ static t_int *NLMS_tilde_perform(t_int *w)
t_float *w_filt_coeff = x->x_w_array_mem_beg;
t_float my, my_err, sum;
t_float beta = x->x_beta;
- t_float gamma = x->x_gamma;
+ t_float gammax = x->x_gamma;
t_int i, j, update_counter;
t_int update = x->x_update;
t_int ord8=n_order&0xfffffff8;
@@ -211,7 +206,7 @@ static t_int *NLMS_tilde_perform(t_int *w)
}
for(j=0; j<ord_residual; j++) // residual
sum += read_in_hist[-j] * read_in_hist[-j]; // [-j] only valid for Musil's double buffer structure
- sum += gamma * gamma * (float)n_order; // convert gamma corresponding to filter order
+ sum += gammax * gammax * (float)n_order; // convert gammax corresponding to filter order
my = beta / sum;// calculate mue
@@ -270,7 +265,7 @@ static void *NLMS_tilde_new(t_symbol *s, t_int argc, t_atom *argv)
t_int i, n_order=39;
t_symbol *w_name;
t_float beta=0.1f;
- t_float gamma=0.00001f;
+ t_float gammax=0.00001f;
if((argc >= 4) &&
IS_A_FLOAT(argv,0) && //IS_A_FLOAT/SYMBOL from iemlib.h
@@ -280,7 +275,7 @@ static void *NLMS_tilde_new(t_symbol *s, t_int argc, t_atom *argv)
{
n_order = (t_int)atom_getintarg(0, argc, argv);
beta = (t_float)atom_getfloatarg(1, argc, argv);
- gamma = (t_float)atom_getfloatarg(2, argc, argv);
+ gammax = (t_float)atom_getfloatarg(2, argc, argv);
w_name = (t_symbol *)atom_getsymbolarg(3, argc, argv);
if(beta < 0.0f)
@@ -288,10 +283,10 @@ static void *NLMS_tilde_new(t_symbol *s, t_int argc, t_atom *argv)
if(beta > 2.0f)
beta = 2.0f;
- if(gamma < 0.0f)
- gamma = 0.0f;
- if(gamma > 1.0f)
- gamma = 1.0f;
+ if(gammax < 0.0f)
+ gammax = 0.0f;
+ if(gammax > 1.0f)
+ gammax = 1.0f;
if(n_order < 2)
n_order = 2;
@@ -306,7 +301,7 @@ static void *NLMS_tilde_new(t_symbol *s, t_int argc, t_atom *argv)
x->x_n_order = n_order;
x->x_update = 0;
x->x_beta = beta;
- x->x_gamma = gamma;
+ x->x_gamma = gammax;
// 2 times in and one time desired_in memory allocation (history)
x->x_in_hist = (t_float *)getbytes(2*x->x_n_order*sizeof(t_float));